netapp_ontap.models.certificate_signing_request API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.certificate_signing_request`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class CertificateSigningRequestSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the CertificateSigningRequest object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `algorithm GET POST`

    Asymmetric Encryption Algorithm.

    Valid choices:

    - rsa
    - ecc
  `csr GET`

    A Certificate Signing Request (CSR) provided to a CA for obtaining a CA-signed certificate.

  `extended_key_usages GET POST PATCH`

    A list of extended key usage extensions.

  `generated_private_key GET`

    Private key generated for the CSR.

  `hash_function GET POST`

    Hashing function.

    Valid choices:

    - sha256
    - sha224
    - sha384
    - sha512
  `key_usages GET POST PATCH`

    A list of key usage extensions.

  `links GET`

    The links field of the certificate_signing_request.

  `security_strength GET POST`

    Security strength of the certificate in bits.

  `subject_alternatives GET POST`

    The subject_alternatives field of the certificate_signing_request.

  `subject_name GET POST`

    Subject name details of the certificate. The format is a list of comma separated key=value pairs.

    Example: C=US,O=NTAP,CN=test.domain.com